; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = 128
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = 
a = a
b = b
c = 
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;- AI -
[Command]
name = "cpu1"
command = U, D, F
time = 1

[Command]
name = "cpu2"
command = U, B, F
time = 1

[Command]
name = "cpu3"
command = U, D, D
time = 1

[Command]
name = "cpu4"
command = F, B, U
time = 1

[Command]
name = "cpu5"
command = U, F, U, B
time = 1

[Command]
name = "cpu6"
command = U, D, B
time = 1

[Command]
name = "cpu7"
command = F, F, B
time = 1

[Command]
name = "cpu8"
command = U, D, U
time = 1

[Command]
name = "cpu9"
command = F, B, B
time = 1

[Command]
name = "cpu10"
command = F, F, B, B
time = 1

[Command]
name = "cpu11"
command = U, U, F
time = 1

[Command]
name = "cpu12"
command = U, B, B
time = 1

[Command]
name = "cpu13"
command = U, B, F, F
time = 1

[Command]
name = "cpu14"
command = U, F, B, U
time = 1

[Command]
name = "cpu15"
command = U, B, F, U
time = 1

[Command]
name = "cpu16"
command = U, B, B, B
time = 1

[Command]
name = "cpu17"
command = U, D, B, F
time = 1

[Command]
name = "cpu18"
command = U, D, B, D
time = 1

[Command]
name = "cpu19"
command = U, D, F, U
time = 1

[Command]
name = "cpu20"
command = U, D, U, B
time = 1

[Command]
name = "cpu21"
command = U, D, F, F
time = 1

[Command]
name = "cpu22"
command = F, F, F, F
time = 1

[Command]
name = "cpu23"
command = U, U, U, D
time = 1

[Command]
name = "cpu24"
command = B, B, B
time = 1

[Command]
name = "cpu25"
command = D, D, D, D
time = 1

[Command]
name = "cpu26"
command = D, D, D
time = 1

[Command]
name = "cpu27"
command = F, F, F
time = 1

[Command]
name = "cpu28"
command = U, U, U
time = 1

[Command]
name = "cpu29"
command = U, U, B, B
time = 1

[Command]
name = "cpu30"
command = D, D, F, F
time = 1


;-| Super Motions |--------------------------------------------------------

;-| Special Motions |------------------------------------------------------

;-| Alternative Basics |---------------------------------------------------
[Command]
name = "Stand Medium Left Punch"     ;Required (do not remove)
command = /B, y
time = 10

[Command]
name = "Stand Medium Right Punch"     ;Required (do not remove)
command = /F, y
time = 10

[Command]
name = "Stand Strong Left Punch"     ;Required (do not remove)
command = /B, x
time = 10

[Command]
name = "Stand Strong Right Punch"     ;Required (do not remove)
command = /F, x
time = 10

[Command]
name = "Stand Strong Right Kick"     ;Required (do not remove)
command = /F, b
time = 10

[Command]
name = "Stand Strong Left Kick"     ;Required (do not remove)
command = /B, b
time = 10

[Command]
name = "Stand Medium Right Kick"     ;Required (do not remove)
command = /F, a
time = 10

[Command]
name = "Stand Medium Left Kick"     ;Required (do not remove)
command = /B, a
time = 10

[Command]
name = "Crouch Medium Right Punch"     ;Required (do not remove)
command = /$DF, y
time = 10

[Command]
name = "Crouch Medium Left Punch"     ;Required (do not remove)
command = /$DB, y
time = 10

[Command]
name = "Crouch Strong Right Punch"     ;Required (do not remove)
command = /$DF, x
time = 10

[Command]
name = "Crouch Strong Left Punch"     ;Required (do not remove)
command = /$DB, x
time = 10

[Command]
name = "Crouch Medium Right Kick"     ;Required (do not remove)
command = /$DF, b
time = 10

[Command]
name = "Crouch Medium Left Kick"     ;Required (do not remove)
command = /$DB, b
time = 10

[Command]
name = "Crouch Strong Right Kick"     ;Required (do not remove)
command = /$DF, a
time = 10

[Command]
name = "Crouch Strong Left Kick"     ;Required (do not remove)
command = /$DB, a
time = 10

[Command]
name = "Evade"
command = F, B, y
time = 20

[Command]
name = "Evade"
command = B, F, y
time = 20

[Command]
name = "Throw 1"
command = $F, x+y
time = 90

[Command]
name = "Throw 2"
command = $F, a+b
time = 90

[Command]
name = "Poppycock"
command = y, y, y 
time = 20

[Command]
name = "Lightning Lance"
command = B, F, x 
time = 15

[Command]
name = "Catapult Punch"
command = ~F,D,DF,F,x
time = 20

[Command]
name = "Catapult Punch"
command = F,D,F,x
time = 20

[Command]
name = "Super 1 (Grab)"
command = D,F,D,F,y
time = 30

[Command]
name = "Super 1 (Grab)"
command =  ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = "Super 3 (Uppcercut Chain)"
command = D,F,D,F,x
time = 30

[Command]
name = "Super 3 (Uppcercut Chain)"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "Super 2 (Lightning Spear)"
command = B,F,B,F,x
time = 30



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
[State -1, AI TRIGGER]
type = Varset
triggerall = RoundState = 2
trigger1 = command = "cpu1"
trigger2 = command = "cpu2"
trigger3 = command = "cpu3"
trigger4 = command = "cpu4"
trigger5 = command = "cpu5"
trigger6 = command = "cpu6"
trigger7 = command = "cpu7"
trigger8 = command = "cpu8"
trigger9 = command = "cpu9"
trigger10 = command = "cpu10"
trigger11 = command = "cpu11"
trigger12 = command = "cpu12"
trigger13 = command = "cpu13"
trigger14 = command = "cpu14"
trigger15 = command = "cpu15"
trigger16 = command = "cpu16"
trigger17 = command = "cpu17"
trigger18 = command = "cpu18"
trigger19 = command = "cpu19"
trigger20 = command = "cpu20"
trigger21 = command = "cpu21"
trigger22 = command = "cpu22"
trigger23 = command = "cpu23"
trigger24 = command = "cpu24"
trigger25 = command = "cpu25"
trigger26 = command = "cpu26"
trigger27 = command = "cpu27"
trigger28 = command = "cpu28"
trigger29 = command = "cpu29"
trigger30 = command = "cpu30"
v = 7
value = 1
;===========================================================================
;---------------------------------------------------------------------------
[State -1, Super 1 (Grab)]
type = ChangeState
value = 14000
triggerall =  var (7) != 1
triggerall = command = "Super 1 (Grab)"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Super 1 (Grab) AI]
type = ChangeState
value = 14000
triggerall =  var (7) 
triggerall = !Win
triggerall = power >= 1000
triggerall = statetype != A
triggerall = P2bodydist X = [0,15] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
trigger1 = ctrl
trigger1 = random <= 700
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact



[State -1, Super 2 (Lightning Spear)]
type = ChangeState
value = 14020
triggerall =  var (7) != 1
triggerall = command = "Super 2 (Lightning Spear)"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Super 2 (Lightning Spear) AI]
type = ChangeState
value = 14020
triggerall =  var (7) 
triggerall = !Win
triggerall = power >= 2000
triggerall = statetype != A
triggerall = P2bodydist X = [0,40] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
trigger1 = ctrl
trigger1 = random <= 700
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact



[State -1, Super 3 (Uppcercut Chain)]
type = ChangeState
value = 14010
triggerall =  var (7) != 1
triggerall = command = "Super 3 (Uppcercut Chain)"
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Super 3 (Uppcercut Chain) AI]
type = ChangeState
value = 14010
triggerall =  var (7) 
triggerall = !Win
triggerall = power >= 3000
triggerall = statetype != A
triggerall = P2bodydist X = [0,25] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
trigger1 = ctrl
trigger1 = random <= 700
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact



[State -1, Poppycock]
type = ChangeState
value = 13000
triggerall =  var (7) != 1
triggerall = command = "Poppycock"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Poppycock AI]
type = ChangeState
value = 13000
triggerall =  var (7)
triggerall = !Win
triggerall = statetype = S
triggerall = P2Statetype != L
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = random <= 500
trigger3 = random <= 500
trigger4 = random <= 500
trigger5 = random <= 500
trigger6 = random <= 500
trigger7=  random <= 500
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Lightning Lance]
type = ChangeState
value = 13010
triggerall =  var (7) != 1
triggerall = command = "Lightning Lance"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Lightning Lance AI]
type = ChangeState
value = 13010
triggerall =  var (7)
triggerall = !Win
triggerall = statetype = S
triggerall = P2bodydist X = [0,100] 
triggerall = P2Statetype != L
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = random <= 500
trigger3 = random <= 500
trigger4 = random <= 500
trigger5 = random <= 500
trigger6 = random <= 500
trigger7=  random <= 500
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Catapult Punch]
type = ChangeState
value = 13020
triggerall =  var (7) != 1
triggerall = command = "Catapult Punch"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Catapult Punch AI]
type = ChangeState
value = 13020
triggerall =  var (7)
triggerall = !Win
triggerall = statetype = S
triggerall = P2bodydist X = [0,20] 
triggerall = P2Statetype != L
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = random <= 500
trigger3 = random <= 500
trigger4 = random <= 500
trigger5 = random <= 500
trigger6 = random <= 500
trigger7=  random <= 500
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact



; Evade
[State -1, Evade]
type = ChangeState
value = 12000
triggerall =  var (7) != 1
triggerall = (Command = "Evade")
trigger1 = (StateType = S) && (Ctrl)

[State -1, Evade AI]
type = ChangeState
value = 12000
triggerall =  var (7)
triggerall =  !Win
trigger1 = (StateType = S) && (Ctrl)
triggerall = p2bodydist x = [0,200]
trigger1 = random <= 200

;Throw 1
[State -1, Throw 1]
type = ChangeState
value = 12009
triggerall =  var (7) != 1
triggerall = command = "Throw 1"
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact

;Throw 1
[State -1, Throw 1 AI]
type = ChangeState
value = 12009
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype = S
triggerall = P2BodyDist X = [0,20] 
triggerall = p2statetype != L
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 120
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact



;Throw 2
[State -1, Throw 2]
type = ChangeState
value = 12019
triggerall =  var (7) != 1
triggerall = command = "Throw 2"
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact


[State -1, Throw 2 AI]
type = ChangeState
value = 12019
triggerall =  var (7)
triggerall =  !Win
triggerall = statetype = S
triggerall = P2BodyDist X = [0,20] 
triggerall = p2statetype != L
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 120
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact


[State -1, Crouch Medium Right Punch]
type = ChangeState
value = 1000
triggerall = var(7) != 1
triggerall = command = "Crouch Medium Right Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 10) && movecontact
trigger6 = (stateno = 1002 & time > 10) && movecontact
trigger6 = (stateno = 1003 & time > 14) && movecontact

[State -1, Crouch Medium Right Punch AI]
type = ChangeState
value = 1000
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,19]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 300
trigger2 = random <= 300
trigger3 = random <= 300
trigger4 = random <= 300
trigger5 = random <= 300
trigger6 = random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 10) && movecontact
trigger6 = (stateno = 1002 & time > 10) && movecontact
trigger6 = (stateno = 1003 & time > 14) && movecontact


[State -1, Crouch Medium Left Punch]
type = ChangeState
value = 1001
triggerall = var(7) != 1
triggerall = command = "Crouch Medium Left Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 14) && movecontact
trigger6 = (stateno = 1002 & time > 10) && movecontact
trigger6 = (stateno = 1003 & time > 35) && movecontact

[State -1, Crouch Medium Left Punch AI]
type = ChangeState
value = 1001
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,19]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 300
trigger2 = random <= 300
trigger3 = random <= 300
trigger4 = random <= 300
trigger5 = random <= 300
trigger6 = random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 14) && movecontact
trigger6 = (stateno = 1002 & time > 10) && movecontact
trigger6 = (stateno = 1003 & time > 35) && movecontact



[State -1, Crouch Strong Right Punch]
type = ChangeState
value = 1002
triggerall = var(7) != 1
triggerall = command = "Crouch Strong Right Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 10) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger6 = (stateno = 1003 & time > 14) && movecontact

[State -1, Crouch Strong Right Punch AI]
type = ChangeState
value = 1002
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,19]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 300
trigger2 = random <= 300
trigger3 = random <= 300
trigger4 = random <= 300
trigger5 = random <= 300
trigger6 = random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 10) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger6 = (stateno = 1003 & time > 14) && movecontact



[State -1, Crouch Strong Left Punch]
type = ChangeState
value = 1003
triggerall = var(7) != 1
triggerall = command = "Crouch Strong Left Punch"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 25) && movecontact


[State -1, Crouch Strong Left Punch AI]
type = ChangeState
value = 1003
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,19]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 300
trigger2 = random <= 300
trigger3 = random <= 300
trigger4 = random <= 300
trigger5 = random <= 300
trigger6 = random <= 300
trigger7 = random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 25) && movecontact






[State -1, Crouch Medium Right Kick]
type = ChangeState
value = 1010
triggerall = var(7) != 1
triggerall = command = "Crouch Medium Right Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Crouch Medium Right Kick AI]
type = ChangeState
value = 1010
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,12]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Crouch Medium Left Kick]
type = ChangeState
value = 1011
triggerall = var(7) != 1
triggerall = command = "Crouch Medium Left Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Crouch Medium Left Kick AI]
type = ChangeState
value = 1011
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,12]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact



[State -1, Crouch Strong Right Kick]
type = ChangeState
value = 1012
triggerall = var(7) != 1
triggerall = command = "Crouch Strong Right Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact

[State -1, Crouch Strong Right Kick AI]
type = ChangeState
value = 1012
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,12]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 20
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Crouch Strong Left Kick]
type = ChangeState
value = 1013
triggerall = var(7) != 1
triggerall = command = "Crouch Strong Left Kick"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact


[State -1, Crouch Strong Left Kick AI]
type = ChangeState
value = 1013
triggerall = var(7) 
triggerall = !Win
triggerall = P2bodydist X = [0,12]
triggerall = P2Statetype != A
triggerall = statetype != A
trigger1 = statetype = C
trigger1 = ctrl
trigger1 = random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 14) && movecontact




; Stand Medium Left Punch
[State -1, Stand Medium Left Punch]
type = ChangeState
value = 900
triggerall =  var (7) != 1
triggerall = command = "Stand Medium Left Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 ) && movecontact
trigger3 = (stateno = 901 && time > 17) && movecontact
trigger4 = (stateno = 902 && time > 28) && movecontact
trigger5 = (stateno = 903 && time > 10) && movecontact

; Stand Medium Left Punch
[State -1, Stand Medium Left Punch AI]
type = ChangeState
value = 900
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 300
trigger2= random <= 300
trigger3= random <= 300
trigger4= random <= 300
trigger5= random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 ) && movecontact
trigger3 = (stateno = 901 && time > 17) && movecontact
trigger4 = (stateno = 902 && time > 28) && movecontact
trigger5 = (stateno = 903 && time > 10) && movecontact


[State -1, Stand Medium Right Punch]
type = ChangeState
value = 901
triggerall =  var (7) != 1
triggerall = command = "Stand Medium Right Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 902 && time > 28) && movecontact
trigger5 = (stateno = 903 && time > 17) && movecontact


[State -1, Stand Medium Right Punch AI]
type = ChangeState
value = 901
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 300
trigger2= random <= 300
trigger3= random <= 300
trigger4= random <= 300
trigger5= random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 902 && time > 28) && movecontact
trigger5 = (stateno = 903 && time > 17) && movecontact

; Stand Strong Left Punch
[State -1, Stand Strong Left Punch]
type = ChangeState
value = 902
triggerall =  var (7) != 1
triggerall = command = "Stand Strong Left Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 24) && movecontact
trigger4 = (stateno = 901 && time > 24) && movecontact
trigger5 = (stateno = 903 && time > 24) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 25) && movecontact


[State -1, Stand Strong Left Punch]
type = ChangeState
value = 902
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 300
trigger2= random <= 300
trigger3= random <= 300
trigger4= random <= 300
trigger5= random <= 300
trigger6= random <= 300
trigger7= random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 24) && movecontact
trigger4 = (stateno = 901 && time > 24) && movecontact
trigger5 = (stateno = 903 && time > 24) && movecontact
trigger6 = (stateno = 1000 & time > 10) && movecontact
trigger6 = (stateno = 1001 & time > 35) && movecontact
trigger6 = (stateno = 1002 & time > 14) && movecontact
trigger7 = (stateno = 1003 & time > 25) && movecontact


; Stand Strong Right Punch
[State -1, Stand Strong Right Punch]
type = ChangeState
value = 903
triggerall =  var (7) != 1
triggerall = command = "Stand Strong Right Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact


; Stand Strong Right Punch
[State -1, Stand Strong Right Punch AI]
type = ChangeState
value = 903
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 300
trigger2= random <= 300
trigger3= random <= 300
trigger4= random <= 300
trigger5= random <= 300
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact


; Stand Strong Right Kick
[State -1, Stand Strong Right Kick]
type = ChangeState
value = 910
triggerall =  var (7) != 1
triggerall = command = "Stand Strong Right Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

; Stand Strong Right Kick
[State -1, Stand Strong Right Kick AI]
type = ChangeState
value = 910
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,10]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

; Stand Strong Left Kick
[State -1, Stand Strong Left Kick]
type = ChangeState
value = 920
triggerall =  var (7) != 1
triggerall = command = "Stand Strong Left Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

[State -1, Stand Strong Left Kick AI]
type = ChangeState
value = 920
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact


; Stand Medium Right Kick
[State -1, Stand Medium Right Kick]
type = ChangeState
value = 930
triggerall =  var (7) != 1
triggerall = command = "Stand Medium Right Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

[State -1, Stand Medium Right Kick AI]
type = ChangeState
value = 930
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

; Stand Medium Left Kick
[State -1, Stand Medium Left Kick]
type = ChangeState
value = 940
triggerall =  var (7) != 1
triggerall = command = "Stand Medium Left Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

; Stand Medium Left Kick
[State -1, Stand Medium Left Kick AI]
type = ChangeState
value = 940
triggerall =  var (7) 
triggerall = !Win
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
trigger1 = ctrl
trigger1= random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact
trigger3 = (stateno = 900 && time > 17) && movecontact
trigger4 = (stateno = 901 && time > 10) && movecontact
trigger5 = (stateno = 902 && time > 28) && movecontact

;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = var(7) != 1
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Taunt AI]
type = ChangeState
value = 195
triggerall = var(7)
triggerall = !Win
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = random <= 0

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(7) != 1
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 && time >6) && movecontact

[State -1, Stand Light Punch AI]
type = ChangeState
value = 200
triggerall = var(7)
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = random <= 500
trigger2 = (stateno = 200 || stateno = 210 && time >6) && movecontact
;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(7) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 && time >5) && movecontact

[State -1, Stand Medium Punch AI]
type = ChangeState
value = 210
triggerall = var(7)
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = random <= 500
trigger2 = random <= 500
trigger2 = (stateno = 200 || stateno = 210 && time >5) && movecontact

;---------------------------------------------------------------------------

; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(7) != 1
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

; Stand Light Kick
[State -1, Stand Light Kick AI]
type = ChangeState
value = 230
triggerall = var(7) 
triggerall = !Win
trigger1 = statetype = S
trigger1 = ctrl
triggerall = random <= 0
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 && time >6) && movecontact
;----------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = var(7) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 && time >6) && movecontact
; Standing Medium Kick

[State -1, Standing Medium Kick AI]
type = ChangeState
value = 240
triggerall = var(7) 
triggerall = !Win
trigger1 = statetype = S
trigger1 = ctrl
trigger1l = random <= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 && time >6) && movecontact
;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(7) != 1
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 && time >6) && movecontact

; Crouching Light Punch
[State -1, Crouching Light Punch AI]
type = ChangeState
value = 400
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype != A
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 450
trigger2 = random <= 450
trigger3 = random <= 450
trigger4 = random <= 450
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact
;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = var(7) != 1
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410 && time >6) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

[State -1, Crouching Medium Punch AI]
type = ChangeState
value = 410
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype != A
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 450
trigger2 = random <= 450
trigger3 = random <= 450
trigger4 = random <= 450
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Crouching Light Kick
[State -1, Crouching Light Kick AI]
type = ChangeState
value = 430
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype != A
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = var(7) != 1
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Crouching Medium Kick
[State -1, Crouching Medium Kick AI]
type = ChangeState
value = 440
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype != A
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random <= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(7) != 1
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

; Jump Light Punch
[State -1, Jump Light Punch AI]
type = ChangeState
value = 600
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,10]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 1

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(7) != 1
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 20 || stateno = 610  && time > 20 || stateno = 630 && time > 20 || stateno = 640 && time > 20) && movecontact

; Jump Medium Punch
[State -1, Jump Medium Punch AI]
type = ChangeState
value = 610
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,10]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 && time > 20 || stateno = 610  && time > 20 || stateno = 630 && time > 20 || stateno = 640 && time > 20) && movecontact

;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(7)  != 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

; Jump Light Kick
[State -1, Jump Light Kick AI]
type = ChangeState
value = 630
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 5

;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(7) != 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

; Jump Medium Kick
[State -1, Jump Medium Kick AI]
type = ChangeState
value = 640
triggerall = var(7) 
triggerall = !Win
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = random <= 5


;---------------------------------------------------------------------------
